@@ -132,11 +132,11 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Add new deanery
     async fn add_deanery(
         &self,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         context: &C) -> Result<AddDeaneryResponse, ApiError>
     {
         let context = context.clone();
-        info!("add_deanery({:?}) - X-Span-ID: {:?}", deanery, context.get().0.clone());
+        info!("add_deanery({:?}) - X-Span-ID: {:?}", deanery_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -180,22 +180,22 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn update_deanery(
         &self,
         id: uuid::Uuid,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_deanery({:?}, {:?}) - X-Span-ID: {:?}", id, deanery, context.get().0.clone());
+        info!("update_deanery({:?}, {:?}) - X-Span-ID: {:?}", id, deanery_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
     /// Add new diocese
     async fn add_diocese(
         &self,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         context: &C) -> Result<AddDioceseResponse, ApiError>
     {
         let context = context.clone();
-        info!("add_diocese({:?}) - X-Span-ID: {:?}", diocese, context.get().0.clone());
+        info!("add_diocese({:?}) - X-Span-ID: {:?}", diocese_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -244,22 +244,22 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn update_diocese(
         &self,
         id: uuid::Uuid,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_diocese({:?}, {:?}) - X-Span-ID: {:?}", id, diocese, context.get().0.clone());
+        info!("update_diocese({:?}, {:?}) - X-Span-ID: {:?}", id, diocese_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
     /// Add new institute
     async fn add_institute(
         &self,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         context: &C) -> Result<AddInstituteResponse, ApiError>
     {
         let context = context.clone();
-        info!("add_institute({:?}) - X-Span-ID: {:?}", institute, context.get().0.clone());
+        info!("add_institute({:?}) - X-Span-ID: {:?}", institute_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -302,22 +302,22 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn update_institute(
         &self,
         id: uuid::Uuid,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         context: &C) -> Result<UpdateInstituteResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_institute({:?}, {:?}) - X-Span-ID: {:?}", id, institute, context.get().0.clone());
+        info!("update_institute({:?}, {:?}) - X-Span-ID: {:?}", id, institute_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
     /// Add new parish
     async fn add_parish(
         &self,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         context: &C) -> Result<AddParishResponse, ApiError>
     {
         let context = context.clone();
-        info!("add_parish({:?}) - X-Span-ID: {:?}", parish, context.get().0.clone());
+        info!("add_parish({:?}) - X-Span-ID: {:?}", parish_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -362,22 +362,22 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn update_parish(
         &self,
         id: uuid::Uuid,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         context: &C) -> Result<UpdateParishResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_parish({:?}, {:?}) - X-Span-ID: {:?}", id, parish, context.get().0.clone());
+        info!("update_parish({:?}, {:?}) - X-Span-ID: {:?}", id, parish_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
     /// Add new province
     async fn add_province(
         &self,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         context: &C) -> Result<AddProvinceResponse, ApiError>
     {
         let context = context.clone();
-        info!("add_province({:?}) - X-Span-ID: {:?}", province, context.get().0.clone());
+        info!("add_province({:?}) - X-Span-ID: {:?}", province_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -421,11 +421,11 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn update_province(
         &self,
         id: uuid::Uuid,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         context: &C) -> Result<UpdateProvinceResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_province({:?}, {:?}) - X-Span-ID: {:?}", id, province, context.get().0.clone());
+        info!("update_province({:?}, {:?}) - X-Span-ID: {:?}", id, province_mutation, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
