@@ -10,14 +10,14 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.8.0";
+pub const API_VERSION: &'static str = "0.9.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
 pub enum AddDeaneryResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Deanery)
+    (models::DeaneryMutation)
     ,
     /// Invalid input
     InvalidInput
@@ -55,7 +55,7 @@ pub enum GetDeaneriesResponse {
 pub enum GetDeaneryByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Deanery)
+    (models::DeaneryView)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -69,7 +69,7 @@ pub enum GetDeaneryByIdResponse {
 pub enum UpdateDeaneryResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Deanery)
+    (models::DeaneryMutation)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -86,7 +86,7 @@ pub enum UpdateDeaneryResponse {
 pub enum AddDioceseResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Diocese)
+    (models::DioceseMutation)
     ,
     /// Invalid input
     InvalidInput
@@ -110,7 +110,7 @@ pub enum DeleteDioceseResponse {
 pub enum GetDioceseByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Diocese)
+    (models::DioceseView)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -138,7 +138,7 @@ pub enum GetDiocesesResponse {
 pub enum UpdateDioceseResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Diocese)
+    (models::DioceseMutation)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -155,7 +155,7 @@ pub enum UpdateDioceseResponse {
 pub enum AddInstituteResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Institute)
+    (models::InstituteMutation)
     ,
     /// Invalid input
     InvalidInput
@@ -179,7 +179,7 @@ pub enum DeleteInstituteResponse {
 pub enum GetInstituteByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Institute)
+    (models::InstituteView)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -207,7 +207,7 @@ pub enum GetInstitutesResponse {
 pub enum UpdateInstituteResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Institute)
+    (models::InstituteMutation)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -224,7 +224,7 @@ pub enum UpdateInstituteResponse {
 pub enum AddParishResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Parish)
+    (models::ParishMutation)
     ,
     /// Invalid input
     InvalidInput
@@ -248,7 +248,7 @@ pub enum DeleteParishResponse {
 pub enum GetParishByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Parish)
+    (models::ParishView)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -276,7 +276,7 @@ pub enum GetParishesResponse {
 pub enum UpdateParishResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Parish)
+    (models::ParishMutation)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -293,7 +293,7 @@ pub enum UpdateParishResponse {
 pub enum AddProvinceResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Province)
+    (models::ProvinceMutation)
     ,
     /// Invalid input
     InvalidInput
@@ -317,7 +317,7 @@ pub enum DeleteProvinceResponse {
 pub enum GetProvinceByIdResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Province)
+    (models::ProvinceView)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -345,7 +345,7 @@ pub enum GetProvincesResponse {
 pub enum UpdateProvinceResponse {
     /// successful operation
     SuccessfulOperation
-    (models::Province)
+    (models::ProvinceMutation)
     ,
     /// Invalid ID supplied
     InvalidIDSupplied
@@ -367,7 +367,7 @@ pub trait Api<C: Send + Sync> {
     /// Add new deanery
     async fn add_deanery(
         &self,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         context: &C) -> Result<AddDeaneryResponse, ApiError>;
 
     /// Delete deanery by ID
@@ -395,13 +395,13 @@ pub trait Api<C: Send + Sync> {
     async fn update_deanery(
         &self,
         id: uuid::Uuid,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>;
 
     /// Add new diocese
     async fn add_diocese(
         &self,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         context: &C) -> Result<AddDioceseResponse, ApiError>;
 
     /// Delete diocese by ID
@@ -434,13 +434,13 @@ pub trait Api<C: Send + Sync> {
     async fn update_diocese(
         &self,
         id: uuid::Uuid,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>;
 
     /// Add new institute
     async fn add_institute(
         &self,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         context: &C) -> Result<AddInstituteResponse, ApiError>;
 
     /// Delete institute by ID
@@ -467,13 +467,13 @@ pub trait Api<C: Send + Sync> {
     async fn update_institute(
         &self,
         id: uuid::Uuid,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         context: &C) -> Result<UpdateInstituteResponse, ApiError>;
 
     /// Add new parish
     async fn add_parish(
         &self,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         context: &C) -> Result<AddParishResponse, ApiError>;
 
     /// Delete parish by ID
@@ -502,13 +502,13 @@ pub trait Api<C: Send + Sync> {
     async fn update_parish(
         &self,
         id: uuid::Uuid,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         context: &C) -> Result<UpdateParishResponse, ApiError>;
 
     /// Add new province
     async fn add_province(
         &self,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         context: &C) -> Result<AddProvinceResponse, ApiError>;
 
     /// Delete province by ID
@@ -536,7 +536,7 @@ pub trait Api<C: Send + Sync> {
     async fn update_province(
         &self,
         id: uuid::Uuid,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         context: &C) -> Result<UpdateProvinceResponse, ApiError>;
 
 }
@@ -552,7 +552,7 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Add new deanery
     async fn add_deanery(
         &self,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         ) -> Result<AddDeaneryResponse, ApiError>;
 
     /// Delete deanery by ID
@@ -580,13 +580,13 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn update_deanery(
         &self,
         id: uuid::Uuid,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         ) -> Result<UpdateDeaneryResponse, ApiError>;
 
     /// Add new diocese
     async fn add_diocese(
         &self,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         ) -> Result<AddDioceseResponse, ApiError>;
 
     /// Delete diocese by ID
@@ -619,13 +619,13 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn update_diocese(
         &self,
         id: uuid::Uuid,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         ) -> Result<UpdateDioceseResponse, ApiError>;
 
     /// Add new institute
     async fn add_institute(
         &self,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         ) -> Result<AddInstituteResponse, ApiError>;
 
     /// Delete institute by ID
@@ -652,13 +652,13 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn update_institute(
         &self,
         id: uuid::Uuid,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         ) -> Result<UpdateInstituteResponse, ApiError>;
 
     /// Add new parish
     async fn add_parish(
         &self,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         ) -> Result<AddParishResponse, ApiError>;
 
     /// Delete parish by ID
@@ -687,13 +687,13 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn update_parish(
         &self,
         id: uuid::Uuid,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         ) -> Result<UpdateParishResponse, ApiError>;
 
     /// Add new province
     async fn add_province(
         &self,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         ) -> Result<AddProvinceResponse, ApiError>;
 
     /// Delete province by ID
@@ -721,7 +721,7 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn update_province(
         &self,
         id: uuid::Uuid,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         ) -> Result<UpdateProvinceResponse, ApiError>;
 
 }
@@ -752,11 +752,11 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Add new deanery
     async fn add_deanery(
         &self,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         ) -> Result<AddDeaneryResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().add_deanery(deanery, &context).await
+        self.api().add_deanery(deanery_mutation, &context).await
     }
 
     /// Delete deanery by ID
@@ -796,21 +796,21 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn update_deanery(
         &self,
         id: uuid::Uuid,
-        deanery: models::Deanery,
+        deanery_mutation: models::DeaneryMutation,
         ) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_deanery(id, deanery, &context).await
+        self.api().update_deanery(id, deanery_mutation, &context).await
     }
 
     /// Add new diocese
     async fn add_diocese(
         &self,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         ) -> Result<AddDioceseResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().add_diocese(diocese, &context).await
+        self.api().add_diocese(diocese_mutation, &context).await
     }
 
     /// Delete diocese by ID
@@ -855,21 +855,21 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn update_diocese(
         &self,
         id: uuid::Uuid,
-        diocese: models::Diocese,
+        diocese_mutation: models::DioceseMutation,
         ) -> Result<UpdateDioceseResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_diocese(id, diocese, &context).await
+        self.api().update_diocese(id, diocese_mutation, &context).await
     }
 
     /// Add new institute
     async fn add_institute(
         &self,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         ) -> Result<AddInstituteResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().add_institute(institute, &context).await
+        self.api().add_institute(institute_mutation, &context).await
     }
 
     /// Delete institute by ID
@@ -908,21 +908,21 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn update_institute(
         &self,
         id: uuid::Uuid,
-        institute: models::Institute,
+        institute_mutation: models::InstituteMutation,
         ) -> Result<UpdateInstituteResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_institute(id, institute, &context).await
+        self.api().update_institute(id, institute_mutation, &context).await
     }
 
     /// Add new parish
     async fn add_parish(
         &self,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         ) -> Result<AddParishResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().add_parish(parish, &context).await
+        self.api().add_parish(parish_mutation, &context).await
     }
 
     /// Delete parish by ID
@@ -963,21 +963,21 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn update_parish(
         &self,
         id: uuid::Uuid,
-        parish: Option<models::Parish>,
+        parish_mutation: Option<models::ParishMutation>,
         ) -> Result<UpdateParishResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_parish(id, parish, &context).await
+        self.api().update_parish(id, parish_mutation, &context).await
     }
 
     /// Add new province
     async fn add_province(
         &self,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         ) -> Result<AddProvinceResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().add_province(province, &context).await
+        self.api().add_province(province_mutation, &context).await
     }
 
     /// Delete province by ID
@@ -1017,11 +1017,11 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn update_province(
         &self,
         id: uuid::Uuid,
-        province: Option<models::Province>,
+        province_mutation: Option<models::ProvinceMutation>,
         ) -> Result<UpdateProvinceResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_province(id, province, &context).await
+        self.api().update_province(id, province_mutation, &context).await
     }
 
 }
